% Filtros para la reconstruccion AC. Válido para ENO.
%     ENTRADAS:
%           nl=numero de nodos a la iquierda de x^{k}_{2i-1}
%           nr=numero de nodos a la derecha de x^{k}_{2i-1}
%           r= grado del polinomio para F (r-1 para f)
%     SALIDAS:
%           muestra en pantalla los coeficientes que multiplican a f^{k-1} para obtenener f^{k}_{2i-1} mediante IA
%
% Autor: José Jaime Noguera.   +INFO: www.uv.es/anims/noguera

function capiamincmccoefi(nl,nr,r)
r=r-1; % Por coherencia con el PDF
A=capiamincmcmatriu(nl,nr,r);
C=(A'*A)^(-1)*A';

for i=1:r+1
   coef(i)=1/(2^(i-1));
end 

solu=coef(1:r+1)*C;

format rational
  solu
format

sprintf('Comienza en f^{k-1}_{i+(%d)} y acaba en f^{k-1}_(i+(%d))',-nl,nr)